import pefile
import json

def analyze(filename):
    pe = pefile.PE(filename)
    try:
        pedump = pe.dump_dict()
        infos = pedump["Version Information"][0][2][5]
        return infos
    except:
        return {}

#"Version Information"
#"Imported Symbols"
#"Resource Directory"



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
import sys
from libsfile import analysis

def main():
    if len(sys.argv) < 2:
        print('Error, at least 2 arguments needed')
        exit(-1)

    filename = sys.argv[1]

    fileobj = analysis.analyzeFile(filename)

    if 'md5' not in fileobj:
        print("Error analyzing file")
        sys.exit(-1)

    print("MD5 HASH:\t\t" + fileobj['md5'])
    print("SHA1 HASH:\t\t" + fileobj['sha1'])
    print("Size: \t\t\t" + str(fileobj['size']) + " bytes")
    print("Mime type:\t\t" + fileobj['mime'])
    print("Description: \t\t" + fileobj['desc'])
    if('detailed' in fileobj):
        print("-----------------------------------------------")
        print("Details:")
        print("-----------------------------------------------")
        for key,value in fileobj['detailed'].items():
            print(key + ": " + str(value))
    






import pikepdf
def analyze(filename):
    try:
        pdf = pikepdf.open(filename)
        meta = pdf.docinfo
        pdf_meta = {}
        for key, value in meta.items():
            pdf_meta[key.replace("/","")] = str(value)
    except:
        pdf_meta = {}
    return pdf_meta


import PIL.Image
import PIL.ExifTags
def analyze(filename):
    try:
        img = PIL.Image.open(filename)
        exif = {
        PIL.ExifTags.TAGS[k]: v
        for k, v in img._getexif().items()
        if k in PIL.ExifTags.TAGS
    }
    except:
        exif = {}
    return exif


import docx

def getMetaData(doc):
    metadata = {}
    prop = doc.core_properties
    metadata["author"] = prop.author
    metadata["category"] = prop.category
    metadata["comments"] = prop.comments
    metadata["content_status"] = prop.content_status
    metadata["created"] = prop.created
    metadata["identifier"] = prop.identifier
    metadata["keywords"] = prop.keywords
    metadata["last_modified_by"] = prop.last_modified_by
    metadata["language"] = prop.language
    metadata["modified"] = prop.modified
    metadata["subject"] = prop.subject
    metadata["title"] = prop.title
    metadata["version"] = prop.version
    return metadata


def analyze(filename):
    try:
        doc = docx.Document(filename)
        metadata_dict = getMetaData(doc)
    except:
        metadata_dict = {}
    return metadata_dict



import hashlib
def md5(fname):
    hash_md5 = hashlib.md5()
    with open(fname, "rb") as f:
        for chunk in iter(lambda: f.read(4096), b""):
            hash_md5.update(chunk)
    return hash_md5.hexdigest()
def sha1(fname):
    hash_sha1 = hashlib.sha1()
    with open(fname, "rb") as f:
        for chunk in iter(lambda: f.read(4096), b""):
            hash_sha1.update(chunk)
    return hash_sha1.hexdigest()


from openpyxl import load_workbook

def analyze(filename):
    metadata = {}
    try:
        wb = load_workbook(filename)
        print(wb.properties)
        metadata["author"] = wb.properties.creator
        metadata["category"] = wb.properties.category
        metadata["content_status"] = wb.properties.contentStatus
        metadata["identifier"] = wb.properties.identifier
        metadata["keywords"] = wb.properties.keywords
        metadata["last_modified_by"] = wb.properties.lastModifiedBy
        metadata["language"] = wb.properties.language
        metadata["modified"] = wb.properties.modified
        metadata["subject"] = wb.properties.subject
        metadata["title"] = wb.properties.title
        metadata["version"] = wb.properties.version
    except:
        metadata = {}
    return metadata


import magic
import os
import libsfile.hashes as hashes
from plugins import exif
from plugins import pdf
from plugins import pe
from plugins import docx
from plugins import xlsx
from plugins import media


def analyzeFile(filename):
    fileobj = {}
    if not os.path.isfile(filename):
        return fileobj

    fileobj['name'] = os.path.basename(filename)
    fileobj['mime'] = magic.from_file(filename,mime=True)
    fileobj['desc'] = magic.from_file(filename)
    fileobj['md5'] = hashes.md5(filename)
    fileobj['sha1'] = hashes.sha1(filename)
    stats = os.stat(filename)
    fileobj['size'] = int(stats.st_size)

    if('application/x-dosexec' in fileobj['mime']):
        fileobj['detailed'] = pe.analyze(filename)
    elif('image' in fileobj['mime']):
        fileobj['detailed'] = exif.analyze(filename)
    elif 'application/pdf' in fileobj['mime']:
        fileobj['detailed'] = pdf.analyze(filename)
    elif 'application/vnd.openxmlformats-officedocument.wordprocessingml.document' in fileobj['mime']:
        fileobj['detailed'] = docx.analyze(filename)
    elif 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet' in fileobj['mime']:
        fileobj['detailed'] = xlsx.analyze(filename)   
    
    return fileobj
